@@ -4,10 +4,12 @@ This is a cutomized python package for plotting and data processing in stellarat
 how to use:
 
 """
-__version__ = '0.2.12'
+__version__ = '0.2.13'
 
 # local packages
-from .misc import colorbar, get_figure, kwargs2dict, map_matrix, print_progress, toroidal_period, vmecMN, xy2rp, trigfft, fft_deriv
+from .misc import colorbar, get_figure, kwargs2dict, map_matrix
+from .misc import print_progress, toroidal_period, vmecMN, xy2rp
+from .misc import trigfft, fft_deriv, trig2real
 from .hdf5 import HDF5
 from .surface import FourSurf
 from .dipole import Dipole
